@@ -5,7 +5,7 @@ use warnings;
 use 5.008001;
 
 # ABSTRACT: Simplified alternative to Alien::FFI that uses system libffi
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 
 1;
@@ -22,7 +22,7 @@ Alt::Alien::FFI::System - Simplified alternative to Alien::FFI that uses system
 
 =head1 VERSION
 
-version 0.12
+version 0.16
 
 =head1 SYNOPSIS
 
@@ -32,8 +32,10 @@ version 0.12
 
 This distribution provides an alternative implementation of
 L<Alien::FFI> that is geared toward system integrators when
-libffi is provided by the operating system.  It requires 
-Perl 5.10 or better, but has no non-core requirements.
+libffi is provided by the operating system.  It has no non-core
+requirements for runtime as of Perl 5.8.  It now uses
+use L<Test::Alien> for consistency with the original
+L<Alien::FFI>.
 
 It will NOT attempt to download or install libffi.  If you
 need that, then install the original L<Alien::FFI> instead.
